# bebi103

Utilities Caltech BE/Bi 103: Data Analysis in the Biological Sciences


## Installation / Usage

To install use pip:

    pip install bebi103


Or clone the repo:

    git clone https://github.com/justinbois/bebi103.git
    python setup.py install
